import os
import sys
import argparse

from colorconsole import terminal
from jt64env import __version__
from jt64env import __summary__


def clear():
    """Clear Screen Function"""
    os.system('cls' if os.name == 'nt' else 'clear')


def env_item(value):
    """Return status of environment variable"""
    status = os.getenv(value)
    return status


def main():
    """Prints JTSDK64 Tools Environment Variables """
    clear()

    # setup the parser
    parser = argparse.ArgumentParser(add_help=True, description=__summary__)
    parser.add_argument('-v', '--version',
                        action='version',
                        version='%(prog)s ' + __version__,
                        help='display module version')

    # process the arguments
    args = parser.parse_args()

    screen = terminal.get_terminal(conEmu=False)
    print("------------------------------------------------------------")
    screen.set_color(3, 0)
    print(f"JTSDK64 Tools {os.environ['VERSION']} Environment Variables")
    screen.reset_colors()
    print("------------------------------------------------------------")
    print("\nJTSDK Variables\n")
    print(f"  JTSDK Version ....: {env_item('JTSDK_VERSION')}")
    print(f"  JTSDK Home .......: {env_item('JTSDK_HOME')}")
    print(f"  JTSDK Config .....: {env_item('JTSDK_CONFIG')}")
    print(f"  JTSDK Data .......: {env_item('JTSDK_DATA')}")
    print(f"  JTSDK Tmp ........: {env_item('JTSDK_TMP')}")
    print(f"  JTSDK Scripts ....: {env_item('JTSDK_SCRIPTS')}")
    print("\nQT Variables\n")
    print(f"  QT Version  ......: {env_item('QTV')}")
    print(f"  QT Directory .....: {env_item('QTD')}")
    print(f"  QT Plugins .......: {env_item('QTP')}")
    print(f"  GCC Directory ....: {env_item('GCCD')}")
    print("\nConfiguration Options\n")
    print(f"  Python Tools .....: {env_item('PYTOOLS')}")
    print(f"  PostgreSQL .......: {env_item('POSTGRES')}")
    print(f"  Unix Tools .......: {env_item('UNIXTOOLS')}")


if __name__ == '__main__':
    main()
    sys.exit(0)



version_info = (0, 0, 17)
__title__ = "jt64env"
__version__ = '.'.join(str(c) for c in version_info)
__name__ = "jt64env"
__author__ = "Greg Beam, KI7MT"
__license__ = "GPLv3"
__email__ = "ki7mt@yahoo.com"
__summary__ = "JTSDK64 Tools Environment Variables"



import os
import setuptools
import jt64env

here = os.path.dirname(os.path.abspath(__file__))

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name=jt64env.__title__,
    version=jt64env.__version__,
    author=jt64env.__author__,
    license=jt64env.__license__,
    author_email=jt64env.__email__,
    long_description=long_description,
    long_description_content_type="text/markdown",

    python_requires='>=3.5.*',
    project_urls={
        'Documentation': 'https://ki7mt.github.io/jtsdk-tools/',
    },
    packages=setuptools.find_packages(),
    install_requires=['colorconsole', 'jt64common'],
    entry_points={
        'console_scripts': ['jt64env = jt64env.__main__:main'],
    },
    classifiers=[
        "Natural Language :: English",
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Topic :: Utilities",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: Microsoft :: Windows",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        ],
    url='https://github.com/KI7MT/jtsdk64-tools/tree/master/src/python/jtsdk64-environment',
)
